==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModTemplatePools.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import com.mojang.datafixers.util.Pair;
import java.util.List;
import net.minecraft.class_3784;
import net.minecraft.class_3785;
import net.minecraft.class_5321;
import net.minecraft.class_5468;
import net.minecraft.class_6880;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModTemplatePools {

    public static final class_5321<class_3785> ABANDONED_ALTAR = getOrCreateRegistryKey("abandon_altar");
    public static final class_5321<class_3785> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_3785> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_3785> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_3785> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_3785> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_3785> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_3785> context) {
        class_7871<class_3785> structurePool = context.method_46799(class_7924.field_41249);
        class_6880.class_6883<class_3785> emptyPool = structurePool.method_46747(class_5468.field_26254);
        context.method_46838(ABANDONED_ALTAR, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.ABANDONED_ALTAR.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(ABANDONED_TORII, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.ABANDONED_TORII.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(MINI_BAR, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.MINI_BAR.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(OUTER_SHRINE, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.OUTER_SHRINE.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(BAMBOO_FOREST_BBQ_STALL, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.BAMBOO_FOREST_BBQ_STALL.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(BAMBOO_FOREST_HUT, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.BAMBOO_FOREST_HUT.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(SAKURAZUKA, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.SAKURAZUKA.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
    }

    public static class_6880.class_6883<class_3785> register(class_7891<class_3785> registry, class_5321<class_3785> registryKey, class_3785 structurePool) {
        return registry.method_46838(registryKey, structurePool);
    }

    public static class_5321<class_3785> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41249, ReverieDreams.id(name));
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ModTemplatePools.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import com.mojang.datafixers.util.Pair;
import java.util.List;
import net.minecraft.class_3784;
import net.minecraft.class_3785;
import net.minecraft.class_5321;
import net.minecraft.class_5468;
import net.minecraft.class_6880;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ModTemplatePools {

    public static final class_5321<class_3785> ABANDONED_ALTAR = getOrCreateRegistryKey("abandon_altar");
    public static final class_5321<class_3785> ABANDONED_TORII = getOrCreateRegistryKey("abandoned_torii");
    public static final class_5321<class_3785> MINI_BAR = getOrCreateRegistryKey("mini_bar");
    public static final class_5321<class_3785> BAMBOO_FOREST_BBQ_STALL = getOrCreateRegistryKey("bamboo_forest_bbq_stall");
    public static final class_5321<class_3785> BAMBOO_FOREST_HUT = getOrCreateRegistryKey("bamboo_forest_hut");
    public static final class_5321<class_3785> SAKURAZUKA = getOrCreateRegistryKey("sakurazuka");
    public static final class_5321<class_3785> OUTER_SHRINE = getOrCreateRegistryKey("outer_shrine");
    public static final class_5321<class_3785> NETHER_HOT_SPRING = getOrCreateRegistryKey("nether_hot_spring");

    public static void init() {

    }

    public static void bootstrap(class_7891<class_3785> context) {
        class_7871<class_3785> structurePool = context.method_46799(class_7924.field_41249);
        class_6880.class_6883<class_3785> emptyPool = structurePool.method_46747(class_5468.field_26254);
        context.method_46838(ABANDONED_ALTAR, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.ABANDONED_ALTAR.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(ABANDONED_TORII, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.ABANDONED_TORII.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(MINI_BAR, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.MINI_BAR.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(OUTER_SHRINE, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.OUTER_SHRINE.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(BAMBOO_FOREST_BBQ_STALL, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.BAMBOO_FOREST_BBQ_STALL.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(BAMBOO_FOREST_HUT, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.BAMBOO_FOREST_HUT.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(SAKURAZUKA, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.SAKURAZUKA.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
        context.method_46838(NETHER_HOT_SPRING, new class_3785(
                emptyPool,
                List.of(Pair.of(class_3784.method_30434(ModStructures.NETHER_HOT_SPRING.method_29177().toString()), 1)), class_3785.class_3786.field_16687)
        );
    }

    public static class_6880.class_6883<class_3785> register(class_7891<class_3785> registry, class_5321<class_3785> registryKey, class_3785 structurePool) {
        return registry.method_46838(registryKey, structurePool);
    }

    public static class_5321<class_3785> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41249, ReverieDreams.id(name));
    }
}
